@@ -225,8 +225,7 @@ define(['./python-code'], (PythonCode) => class JupyterKernel {
                 if (that.expectStream) {
                   responseNumber += 1;
                   that.showDebug && console.log(`RESPONSE #${responseNumber}:`, out);
-                  if (responseNumber !== that.expectStream) return;
-                  that.showDebug && console.log('EXPECTED RESPONSE INDEX, saving...');
+                  return;
                 }
                 solution.output = out;
                 if (!that.hasCell && !that.expectStream) {
