@@ -1,12 +1,13 @@
 __title__ = "mstrio-py"
-__version__ = "11.3.1.102"  # NOSONAR
+__version__ = "11.3.2.101"  # NOSONAR
 __license__ = "Apache License 2.0"
 __description__ = "Python interface for the MicroStrategy REST API"
 __author__ = ("Scott Rigney, Peter Ott, Sergio Sainz Palacios, Michal Ciesielski, Zofia Rogala, "
               "Ignacy Hologa, Piotr Czyz, Oskar Duda, Wojciech Antonczyk, Michal Drzazga, "
-              "Adam Piotrowski")
+              "Adam Piotrowski, Agnieszka Olech, Filip Szymanski, Tomasz Marianski")
 __author_email__ = (
     "srigney@microstrategy.com, ssainz@microstrategy.com, mciesielski@microstrategy.com, "
     "zrogala@microstrategy.com, ihologa@microstrategy.com, pczyz@microstrategy.com, "
     "oduda@microstrategy.com, wantonczyk@microstrategy.com, mdrzazga@microstrategy.com, "
-    "apiotrowski@microstrategy.com")
+    "apiotrowski@microstrategy.com, aolech@microstrategy.com, fszymanski@microstrategy.com, "
+    "tmarianski@microstrategy.com")
