@@ -1,7 +1,8 @@
 from mstrio.utils.helper import response_handler
 
 
-def get_dossiers(connection, search_term, certified_status, search_pattern='EXACTLY', offset=0, limit=-1, fields=None, error_msg=None):
+def get_dossiers(connection, search_term, certified_status, search_pattern='EXACTLY', offset=0,
+                 limit=-1, fields=None, error_msg=None):
     """Get the list of available dossiers.
 
     Args:
@@ -12,12 +13,16 @@ def get_dossiers(connection, search_term, certified_status, search_pattern='EXAC
         Complete HTTP response object.
     """
     url = connection.base_url + "/api/dossiers"
-    response = connection.session.get(url=url,
-                                      params={'searchTerm': search_term,
-                                              'searchPattern': search_pattern,
-                                              'offset': offset,
-                                              'limit': limit,
-                                              'fields': fields})
+    response = connection.session.get(
+        url=url,
+        params={
+            'searchTerm': search_term,
+            'searchPattern': search_pattern,
+            'offset': offset,
+            'limit': limit,
+            'fields': fields
+        },
+    )
     if not response.ok:
         if error_msg is None:
             error_msg = "Error getting available dossiers"
@@ -25,7 +30,8 @@ def get_dossiers(connection, search_term, certified_status, search_pattern='EXAC
     return response
 
 
-def get_dossiers_async(future_session, connection, search_term, certified_status, search_pattern='EXACTLY', offset=0, limit=-1, fields=None, error_msg=None):
+def get_dossiers_async(future_session, connection, search_term, certified_status,
+                       search_pattern='EXACTLY', offset=0, limit=-1, fields=None, error_msg=None):
     """Get the list of available dossiers asynchronously.
 
     Args:
@@ -35,18 +41,21 @@ def get_dossiers_async(future_session, connection, search_term, certified_status
     Returns:
         Complete HTTP response object.
     """
-    connection._validate_project_selected()
+    connection._validate_application_selected()
     url = connection.base_url + "/api/dossiers"
-    params = {'searchTerm': search_term,
-              'searchPattern': search_pattern,
-              'offset': offset,
-              'limit': limit,
-              'fields': fields}
+    params = {
+        'searchTerm': search_term,
+        'searchPattern': search_pattern,
+        'offset': offset,
+        'limit': limit,
+        'fields': fields
+    }
     future = future_session.get(url=url, params=params)
     return future
 
 
-def get_documents(connection, search_term, certified_status, search_pattern='EXACTLY', offset=0, limit=-1, fields=None, error_msg=None):
+def get_documents(connection, search_term, certified_status, search_pattern='EXACTLY', offset=0,
+                  limit=-1, fields=None, error_msg=None):
     """Get the list of available documents.
 
     Args:
@@ -57,12 +66,16 @@ def get_documents(connection, search_term, certified_status, search_pattern='EXA
         Complete HTTP response object.
     """
     url = connection.base_url + '/api/documents/'
-    response = connection.session.get(url,
-                                      params={'searchTerm': search_term,
-                                              'searchPattern': search_pattern,
-                                              'offset': offset,
-                                              'limit': limit,
-                                              'fields': fields})
+    response = connection.session.get(
+        url,
+        params={
+            'searchTerm': search_term,
+            'searchPattern': search_pattern,
+            'offset': offset,
+            'limit': limit,
+            'fields': fields
+        },
+    )
     if not response.ok:
         if error_msg is None:
             error_msg = "Error getting available documents"
@@ -70,7 +83,8 @@ def get_documents(connection, search_term, certified_status, search_pattern='EXA
     return response
 
 
-def get_documents_async(future_session, connection, search_term, certified_status, search_pattern='EXACTLY', offset=0, limit=-1, fields=None, error_msg=None):
+def get_documents_async(future_session, connection, search_term, certified_status,
+                        search_pattern='EXACTLY', offset=0, limit=-1, fields=None, error_msg=None):
     """Get the list of available documents asynchronously.
 
     Args:
@@ -81,11 +95,13 @@ def get_documents_async(future_session, connection, search_term, certified_statu
         Complete HTTP response object.
     """
     url = connection.base_url + '/api/documents/'
-    params = {'searchTerm': search_term,
-              'searchPattern': search_pattern,
-              'offset': offset,
-              'limit': limit,
-              'fields': fields}
+    params = {
+        'searchTerm': search_term,
+        'searchPattern': search_pattern,
+        'offset': offset,
+        'limit': limit,
+        'fields': fields
+    }
     future = future_session.get(url=url, params=params)
     return future
 
@@ -102,7 +118,7 @@ def get_document_status(connection, document_id, instance_id, error_msg=None):
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/documents​/{document_id}​/instances​/{instance_id}​/status"
+    url = f"{connection.base_url}​/api​/documents​/{document_id}​/instances​/{instance_id}​/status"
     response = connection.session.get(url=url, headers={'X-MSTR-ProjectID': None})
     if not response.ok:
         if error_msg is None:
@@ -124,7 +140,7 @@ def get_prompts_for_instance(connection, document_id, instance_id, error_msg=Non
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/documents​/{document_id}​/instances​/{instance_id}​/prompts"
+    url = f"{connection.base_url}​/api​/documents​/{document_id}​/instances​/{instance_id}​/prompts"  # noqa
     response = connection.session.get(url=url, headers={'X-MSTR-ProjectID': None})
     if not response.ok:
         if error_msg is None:
@@ -133,8 +149,8 @@ def get_prompts_for_instance(connection, document_id, instance_id, error_msg=Non
     return response
 
 
-def get_attribute_element_for_prompt(connection, document_id, instance_id,
-                                     prompt_identifier, error_msg=None):
+def get_attribute_element_for_prompt(connection, document_id, instance_id, prompt_identifier,
+                                     error_msg=None):
     """Get available attribute element for document/dossier's attribute element
     prompt.
 
@@ -148,7 +164,7 @@ def get_attribute_element_for_prompt(connection, document_id, instance_id,
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/documents​/{document_id}​/instances​/{instance_id}​/prompts​/{prompt_identifier}​/elements"
+    url = f"{connection.base_url}​/api​/documents​/{document_id}​/instances​/{instance_id}​/prompts​/{prompt_identifier}​/elements"  # noqa
     response = connection.session.get(url=url, headers={'X-MSTR-ProjectID': None})
     if not response.ok:
         if error_msg is None:
@@ -157,8 +173,7 @@ def get_attribute_element_for_prompt(connection, document_id, instance_id,
     return response
 
 
-def get_available_object(connection, document_id, instance_id, prompt_identifier,
-                         error_msg=None):
+def get_available_object(connection, document_id, instance_id, prompt_identifier, error_msg=None):
     """Get available object for answering all kinds of prompts.
 
     Args:
@@ -171,7 +186,7 @@ def get_available_object(connection, document_id, instance_id, prompt_identifier
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/documents​/{document_id}​/instances​/{instance_id}​/prompts​/{prompt_identifier}​/objects"
+    url = f"{connection.base_url}/api​/documents​/{document_id}​/instances​/{instance_id}​/prompts​/{prompt_identifier}​/objects"  # noqa
     response = connection.session.get(url=url, headers={'X-MSTR-ProjectID': None})
     if not response.ok:
         if error_msg is None:
@@ -180,8 +195,8 @@ def get_available_object(connection, document_id, instance_id, prompt_identifier
     return response
 
 
-def export_visualization_to_pdf(connection, document_id, instance_id, node_key,
-                                body, error_msg=None):
+def export_visualization_to_pdf(connection, document_id, instance_id, node_key, body,
+                                error_msg=None):
     """Export a single visualization from a specific document instance to a PDF
     file.
 
@@ -189,17 +204,14 @@ def export_visualization_to_pdf(connection, document_id, instance_id, node_key,
         connection: MicroStrategy REST API connection object
         document_id (string): Document ID
         instance_id (string): Document Instance ID
-        node_key (string): Visualization node key
         body: JSON-formatted information used to format the document
         error_msg (string, optional): Custom Error Message for Error Handling
 
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/documents​/{document_id}​/instances​/{instance_id}​/visualizations​/{node_key}​/pdf"
-    response = connection.session.post(url=url,
-                                       headers={'X-MSTR-ProjectID': None},
-                                       json=body)
+    url = f"{connection.base_url}​/api​/documents​/{document_id}​/instances​/{instance_id}​/visualizations​/{node_key}​/pdf"  # noqa
+    response = connection.session.post(url=url, headers={'X-MSTR-ProjectID': None}, json=body)
     if not response.ok:
         if error_msg is None:
             error_msg = f"Error exporting visualization for document {document_id} to PDF file"
@@ -207,8 +219,8 @@ def export_visualization_to_pdf(connection, document_id, instance_id, node_key,
     return response
 
 
-def export_visualization_to_csv(connection, document_id, instance_id, node_key,
-                                body, error_msg=None):
+def export_visualization_to_csv(connection, document_id, instance_id, node_key, body,
+                                error_msg=None):
     """Export a single visualization from a specific document instance to a CSV
     file.
 
@@ -223,10 +235,8 @@ def export_visualization_to_csv(connection, document_id, instance_id, node_key,
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/documents​/{document_id}​/instances​/{instance_id}​/visualizations​/{node_key}​/csv"
-    response = connection.session.post(url=url,
-                                       headers={'X-MSTR-ProjectID': None},
-                                       json=body)
+    url = f"{connection.base_url}​/api​/documents​/{document_id}​/instances​/{instance_id}​/visualizations​/{node_key}​/csv"  # noqa
+    response = connection.session.post(url=url, headers={'X-MSTR-ProjectID': None}, json=body)
     if not response.ok:
         if error_msg is None:
             error_msg = f"Error exporting visualization for document {document_id} to CSV file"
@@ -234,8 +244,7 @@ def export_visualization_to_csv(connection, document_id, instance_id, node_key,
     return response
 
 
-def export_document_to_pdf(connection, document_id, instance_id, body,
-                           error_msg=None):
+def export_document_to_pdf(connection, document_id, instance_id, body, error_msg=None):
     """Export a specific document instance to a PDF file.
 
     Args:
@@ -248,10 +257,8 @@ def export_document_to_pdf(connection, document_id, instance_id, body,
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/documents​/{document_id}​/instances​/{instance_id}​/pdf"
-    response = connection.session.post(url=url,
-                                       headers={'X-MSTR-ProjectID': None},
-                                       json=body)
+    url = f"{connection.base_url}​/api​/documents​/{document_id}​/instances​/{instance_id}​/pdf"
+    response = connection.session.post(url=url, headers={'X-MSTR-ProjectID': None}, json=body)
     if not response.ok:
         if error_msg is None:
             error_msg = f"Error exporting document {document_id} to PDF file"
@@ -259,8 +266,7 @@ def export_document_to_pdf(connection, document_id, instance_id, body,
     return response
 
 
-def export_document_to_mstr(connection, document_id, instance_id, body,
-                            error_msg=None):
+def export_document_to_mstr(connection, document_id, instance_id, body, error_msg=None):
     """Export a specific document in a specific project to an .mstr file.
 
     Args:
@@ -273,10 +279,8 @@ def export_document_to_mstr(connection, document_id, instance_id, body,
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/documents​/{document_id}​/instances​/{instance_id}​/mstr"
-    response = connection.session.post(url=url,
-                                       headers={'X-MSTR-ProjectID': None},
-                                       json=body)
+    url = f"{connection.base_url}​/api​/documents​/{document_id}​/instances​/{instance_id}​/mstr"
+    response = connection.session.post(url=url, headers={'X-MSTR-ProjectID': None}, json=body)
     if not response.ok:
         if error_msg is None:
             error_msg = f"Error exporting document {document_id} to .mstr file"
@@ -284,8 +288,7 @@ def export_document_to_mstr(connection, document_id, instance_id, body,
     return response
 
 
-def export_document_to_excel(connection, document_id, instance_id, body,
-                             error_msg=None):
+def export_document_to_excel(connection, document_id, instance_id, body, error_msg=None):
     """Export a document from a specific document instance to an Excel file.
 
     Args:
@@ -298,10 +301,8 @@ def export_document_to_excel(connection, document_id, instance_id, body,
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/documents​/{document_id}​/instances​/{instance_id}​/excel"
-    response = connection.session.post(url=url,
-                                       headers={'X-MSTR-ProjectID': None},
-                                       json=body)
+    url = f"{connection.base_url}​/api​/documents​/{document_id}​/instances​/{instance_id}​/excel"
+    response = connection.session.post(url=url, headers={'X-MSTR-ProjectID': None}, json=body)
     if not response.ok:
         if error_msg is None:
             error_msg = f"Error exporting document {document_id} to Excel file"
@@ -309,8 +310,7 @@ def export_document_to_excel(connection, document_id, instance_id, body,
     return response
 
 
-def set_document_to_prompt_status(connection, document_id, instance_id,
-                                  error_msg=None):
+def set_document_to_prompt_status(connection, document_id, instance_id, error_msg=None):
     """Export a document from a specific document instance to an Excel file.
 
     Args:
@@ -322,9 +322,8 @@ def set_document_to_prompt_status(connection, document_id, instance_id,
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/documents​/{document_id}​/instances​/{instance_id}​/rePrompt"
-    response = connection.session.post(url=url,
-                                       headers={'X-MSTR-ProjectID': None})
+    url = f"{connection.base_url}​/api​/documents​/{document_id}​/instances​/{instance_id}​/rePrompt"  # noqa
+    response = connection.session.post(url=url, headers={'X-MSTR-ProjectID': None})
     if not response.ok:
         if error_msg is None:
             error_msg = f"Error setting document {document_id} to prompt status"
@@ -344,7 +343,7 @@ def get_cubes_used_by_document(connection, document_id, error_msg=None):
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"/api/documents/{document_id}/cubes"
+    url = f"{connection.base_url}/api/documents/{document_id}/cubes"
     response = connection.session.get(url=url)
     if not response.ok:
         if error_msg is None:
@@ -365,9 +364,8 @@ def overwrite_document(connection, document_id, instance_id, error_msg=None):
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/documents​/{document_id}​/instances​/{instance_id}​/save"
-    response = connection.session.post(url=url,
-                                       headers={'X-MSTR-ProjectID': None})
+    url = f"{connection.base_url}​/api​/documents​/{document_id}​/instances​/{instance_id}​/save"
+    response = connection.session.post(url=url, headers={'X-MSTR-ProjectID': None})
     if not response.ok:
         if error_msg is None:
             error_msg = f"Error overwriting document {document_id}"
@@ -387,9 +385,8 @@ def save_document_as(connection, document_id, instance_id, error_msg=None):
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/documents​/{document_id}​/instances​/{instance_id}​/saveAs"
-    response = connection.session.post(url=url,
-                                       headers={'X-MSTR-ProjectID': None})
+    url = f"{connection.base_url}/api​/documents​/{document_id}​/instances​/{instance_id}​/saveAs"  # noqa
+    response = connection.session.post(url=url, headers={'X-MSTR-ProjectID': None})
     if not response.ok:
         if error_msg is None:
             error_msg = f"Error saving document {document_id}"
@@ -397,8 +394,7 @@ def save_document_as(connection, document_id, instance_id, error_msg=None):
     return response
 
 
-def create_new_document_instance(connection, document_id, body,
-                                 error_msg=None):
+def create_new_document_instance(connection, document_id, body, error_msg=None):
     """Execute a specific document in a specific project and create an instance
     of the document.
 
@@ -410,9 +406,8 @@ def create_new_document_instance(connection, document_id, body,
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"/api/documents/{document_id}/instances"
-    response = connection.session.post(url=url,
-                                       json=body)
+    url = f"{connection.base_url}/api/documents/{document_id}/instances"
+    response = connection.session.post(url=url, json=body)
     if not response.ok:
         if error_msg is None:
             error_msg = f"Error creating instance for document {document_id}"
@@ -432,9 +427,8 @@ def delete_document_instance(connection, document_id, instance_id, error_msg=Non
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/documents​/{document_id}​/instances​/{instance_id}​/"
-    response = connection.session.delete(url=url,
-                                         headers={'X-MSTR-ProjectID': None})
+    url = f"{connection.base_url}​/api​/documents​/{document_id}​/instances​/{instance_id}​"
+    response = connection.session.delete(url=url, headers={'X-MSTR-ProjectID': None})
     if not response.ok:
         if error_msg is None:
             error_msg = f"Error deleting document instance {instance_id}"
@@ -455,9 +449,8 @@ def refresh_document_instance(connection, document_id, instance_id, error_msg=No
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/documents​/{document_id}​/instances/{instance_id}/refresh​"
-    response = connection.session.put(url=url,
-                                      headers={'X-MSTR-ProjectID': None})
+    url = f"{connection.base_url}​/api​/documents​/{document_id}​/instances/{instance_id}/refresh​"
+    response = connection.session.put(url=url, headers={'X-MSTR-ProjectID': None})
     if not response.ok:
         if error_msg is None:
             error_msg = f"Error refreshing document instance {instance_id}"
@@ -477,7 +470,7 @@ def get_prompts(connection, document_id, error_msg=None):
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/documents​/{document_id}​/prompts"
+    url = f"{connection.base_url}​/api​/documents​/{document_id}​/prompts"
     response = connection.session.get(url=url, headers={'X-MSTR-ProjectID': None})
     if not response.ok:
         if error_msg is None:
@@ -486,8 +479,7 @@ def get_prompts(connection, document_id, error_msg=None):
     return response
 
 
-def answer_prompts(connection, document_id, instance_id, body,
-                   error_msg=None):
+def answer_prompts(connection, document_id, instance_id, body, error_msg=None):
     """Answer specified prompts on the document/dossier instance, prompts can
     either be answered with default answers(if available), the appropriate
     answers, or if the prompt is not required the prompt can simply be closed.
@@ -502,10 +494,8 @@ def answer_prompts(connection, document_id, instance_id, body,
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/documents​/{document_id}​/instances/{instance_id}/prompts/answers"
-    response = connection.session.put(url=url,
-                                      headers={'X-MSTR-ProjectID': None},
-                                      json=body)
+    url = f"{connection.base_url}/api​/documents​/{document_id}​/instances/{instance_id}/prompts/answers"  # noqa
+    response = connection.session.put(url=url, headers={'X-MSTR-ProjectID': None}, json=body)
     if not response.ok:
         if error_msg is None:
             error_msg = f"Error answering prompt for instance {instance_id}"
@@ -513,8 +503,7 @@ def answer_prompts(connection, document_id, instance_id, body,
     return response
 
 
-def get_document_shortcut(connection, document_id, instance_id,
-                          error_msg=None):
+def get_document_shortcut(connection, document_id, instance_id, error_msg=None):
     """Retrieve a published shortcut from a specific document instance.
 
     Args:
@@ -526,7 +515,7 @@ def get_document_shortcut(connection, document_id, instance_id,
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/documents​/{document_id}​/instances/{instance_id}/shortcut"
+    url = f"{connection.base_url}/api​/documents​/{document_id}​/instances/{instance_id}/shortcut"
     response = connection.session.get(url=url)
     if not response.ok:
         if error_msg is None:
@@ -547,10 +536,8 @@ def create_dossier_instance(connection, dossier_id, body, error_msg=None):
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/dossiers/{dossier_id}​/instances​"
-    response = connection.session.post(url=url,
-                                       headers={'X-MSTR-ProjectID': None},
-                                       json=body)
+    url = f"{connection.base_url}​/api​/dossiers/{dossier_id}​/instances​"
+    response = connection.session.post(url=url, headers={'X-MSTR-ProjectID': None}, json=body)
     if not response.ok:
         if error_msg is None:
             error_msg = f"Error creating instance for dossier {dossier_id}"
@@ -569,9 +556,8 @@ def get_dossier_hierarchy(connection, id, error_msg=None):
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"/api/v2/dossiers/{id}/definition/"
-    response = connection.session.get(url=url,
-                                      headers={'X-MSTR-ProjectID': None})
+    url = f"{connection.base_url}/api/v2/dossiers/{id}/definition/"
+    response = connection.session.get(url=url, headers={'X-MSTR-ProjectID': None})
     if not response.ok:
         if error_msg is None:
             error_msg = f"Error getting hierarchy for dossier {id}"
@@ -590,9 +576,8 @@ def get_document_definition(connection, id, error_msg=None):
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"/api/v2/documents/{id}"
-    response = connection.session.get(url=url,
-                                      headers={'X-MSTR-ProjectID': None})
+    url = f"{connection.base_url}/api/v2/documents/{id}"
+    response = connection.session.get(url=url, headers={'X-MSTR-ProjectID': None})
     if not response.ok:
         if error_msg is None:
             error_msg = f"Error getting definition of document {id}"
@@ -600,8 +585,7 @@ def get_document_definition(connection, id, error_msg=None):
     return response
 
 
-def get_dossier_hierarchy_from_instance(connection, dossier_id, instance_id,
-                                        error_msg=None):
+def get_dossier_hierarchy_from_instance(connection, dossier_id, instance_id, error_msg=None):
     """Get the hierarchy of a specific dossier in a specific project from
     instance.
 
@@ -614,7 +598,7 @@ def get_dossier_hierarchy_from_instance(connection, dossier_id, instance_id,
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api​/v2/dossiers/{dossier_id}/​instances/{instance_id}/definition"
+    url = f"{connection.base_url}/api​/v2/dossiers/{dossier_id}/​instances/{instance_id}/definition"  # noqa
     response = connection.session.get(url=url, headers={'X-MSTR-ProjectID': None})
     if not response.ok:
         if error_msg is None:
@@ -623,10 +607,8 @@ def get_dossier_hierarchy_from_instance(connection, dossier_id, instance_id,
     return response
 
 
-def get_definition_and_results_of_visualization(connection, dossier_id,
-                                                instance_id, chapter_key,
-                                                visualization_key,
-                                                error_msg=None):
+def get_definition_and_results_of_visualization(connection, dossier_id, instance_id, chapter_key,
+                                                visualization_key, error_msg=None):
     """Get the definition and data result of a grid/graph visualization in a
     specific dossier in a specific project.
 
@@ -639,7 +621,7 @@ def get_definition_and_results_of_visualization(connection, dossier_id,
     Returns:
         Complete HTTP response object.
     """
-    url = connection.base_url + f"​/api/​v2/dossiers​/{dossier_id}​/instances​/{instance_id}​/chapters​/{chapter_key}​/visualizations​/{visualization_key}"
+    url = f"{connection.base_url}/api/​v2/dossiers​/{dossier_id}​/instances​/{instance_id}​/chapters​/{chapter_key}​/visualizations​/{visualization_key}"  # noqa
     response = connection.session.get(url=url, headers={'X-MSTR-ProjectID': None})
     if not response.ok:
         if error_msg is None:
