@@ -3,18 +3,19 @@ from typing import List, Optional, TYPE_CHECKING, Union
 from pandas import DataFrame, read_csv
 from requests.exceptions import HTTPError
 
+from mstrio import config
+from mstrio.access_and_security.privilege_mode import PrivilegeMode
 from mstrio.access_and_security.security_role import SecurityRole
 from mstrio.api import users
-import mstrio.config as config
 from mstrio.connection import Connection
 from mstrio.users_and_groups.user_connections import UserConnections
 from mstrio.utils import helper
-from mstrio.utils.entity import (Entity, ObjectTypes, Permissions, set_custom_permissions,
-                                 set_permission)
-from mstrio.access_and_security.privilege_mode import PrivilegeMode
+from mstrio.utils.acl import TrusteeACLMixin
+from mstrio.utils.entity import Entity, ObjectTypes
 
 if TYPE_CHECKING:
     from mstrio.access_and_security.privilege import Privilege
+    from mstrio.access_and_security.security_filter import SecurityFilter
     from mstrio.server.application import Application
     from mstrio.users_and_groups.user_group import UserGroup
 
@@ -50,8 +51,8 @@ def list_users(connection: Connection, name_begins: Optional[str] = None,
         abbreviation_begins: characters that the abbreviation must begin with.
         to_dictionary: If True returns dict, by default (False) returns
             User objects.
-        limit: limit the number of elements returned. If `None`, all objects are
-            returned.
+        limit: limit the number of elements returned. If `None` (default), all
+            objects are returned.
         **filters: Available filter parameters: ['id', 'name', 'abbreviation',
             'description', 'type', 'subtype', 'date_created', 'date_modified',
             'version', 'acg', 'icon_path', 'owner', 'initials']
@@ -69,7 +70,7 @@ def list_users(connection: Connection, name_begins: Optional[str] = None,
     )
 
 
-class User(Entity):
+class User(Entity, TrusteeACLMixin):
     """Object representation of MicroStrategy User object.
 
     Attributes:
@@ -127,8 +128,12 @@ class User(Entity):
         'security_roles': users.get_user_security_roles,
         'privileges': users.get_user_privileges,
     }
-    # TODO add basic patch endpoint from entity similar to _API_GETTERS
-    _API_PATCH = [users.update_user_info]
+    _API_PATCH: dict = {
+        ('name', 'abbreviation', 'username', 'full_name', 'enabled', 'password', 'description',
+         'password_modifiable', 'require_new_password', 'password_expiration_date',
+         'standard_auth', 'ldapdn', 'trust_id', 'initials', 'privileges', 'memberships',
+         'addresses', 'security_roles'): (users.update_user_info, 'patch')
+    }
 
     def __init__(self, connection: Connection, username: Optional[str] = None,
                  name: Optional[str] = None, id: Optional[str] = None) -> None:
@@ -398,7 +403,7 @@ class User(Entity):
         Deleting the user will not remove the user's shared files.
 
         Args:
-            force: If True, no additional prompt will be showed before deleting
+            force: If True, no additional prompt will be shown before deleting
                 User.
 
         Returns:
@@ -449,79 +454,6 @@ class User(Entity):
         existing_ids = [obj.get('id') for obj in memberships]
         self.remove_from_user_groups(user_groups=existing_ids)
 
-    def set_permission(self, permission: Permissions, to_objects: Union[str, List[str]],
-                       object_type: ObjectTypes,
-                       application: Optional[Union[str, "Application"]] = None,
-                       propagate_to_children: Optional[bool] = None):
-        """Set permission to perform actions on given object(s).
-
-        Function is used to set permission of the trustee to perform given
-        actions on the provided objects. Within one execution of the function
-        permission will be set in the same manner for each of the provided
-        objects.
-        Permission is the predefined set of rights. All objects to which the
-        rights will be given have to be of the same type which is also provided.
-
-        Args:
-            permission: The Permission which defines set of rights.
-                See: `Permissions` enum
-            to_objects: (str, list(str)): List of object ids on access list
-                to which the permissions will be set
-            object_type: Type of objects on access list
-            application (str, Application): Object or id of Application in which
-                the object is located. If not passed, Application
-                (application_id) selected in Connection object is used.
-            propagate_to_children: Flag used in the request to determine if
-                those rights will be propagated to children of the user group
-        """
-        set_permission(connection=self.connection, trustee_id=self.id, permission=permission,
-                       to_objects=to_objects, object_type=object_type, application=application,
-                       propagate_to_children=propagate_to_children)
-
-    def set_custom_permissions(self, to_objects: Union[str, List[str]], object_type: ObjectTypes,
-                               application: Optional[Union[str, "Application"]] = None,
-                               execute: Optional[str] = None, use: Optional[str] = None,
-                               control: Optional[str] = None, delete: Optional[str] = None,
-                               write: Optional[str] = None, read: Optional[str] = None,
-                               browse: Optional[str] = None):
-        """Set custom permissions to perform actions on given object(s).
-
-        Function is used to set rights of the trustee to perform given actions
-        on the provided objects. Within one execution of the function rights
-        will be set in the same manner for each of the provided objects.
-        None of the rights is necessary, but if provided then only possible
-        values are 'grant' (to grant right), 'deny' (to deny right), 'default'
-        (to reset right) or None which is default value and means that nothing
-        will be changed for this right. All objects to which the rights will be
-        given have to be of the same type which is also provided.
-
-        Args:
-            to_objects: (str, list(str)): List of object ids on access list to
-                which the permissions will be set
-            object_type (int): Type of objects on access list
-            application (str, Application): Object or id of Application in which
-                the object is located. If not passed, Application
-                (application_id) selected in Connection object is used.
-            execute (str): value for right "Execute". Available are 'grant',
-                'deny', 'default' or None
-            use (str): value for right "Use". Available are 'grant',
-                'deny', 'default' or None
-            control (str): value for right "Control". Available are 'grant',
-                'deny', 'default' or None
-            delete (str): value for right "Delete". Available are 'grant',
-                'deny', 'default' or None
-            write  (str): value for right "Write". Available are 'grant',
-                'deny', 'default' or None
-            read (str): value for right "Read". Available are 'grant',
-                'deny', 'default' or None
-            browse (str): value for right "Browse. Available are 'grant',
-                'deny', 'default' or None
-        """
-        set_custom_permissions(connection=self.connection, trustee_id=self.id,
-                               to_objects=to_objects, object_type=object_type,
-                               application=application, execute=execute, use=use, control=control,
-                               delete=delete, write=write, read=read, browse=browse)
-
     def assign_security_role(self, security_role: Union[SecurityRole, str],
                              application: Union["Application", str]) -> None:
         """Assigns a Security Role to the user for given application.
@@ -554,6 +486,35 @@ class User(Entity):
             print("Revoked Security Role '{}' from user: '{}'".format(
                 security_role.name, self.name))
 
+    def apply_security_filter(self, security_filter: Union["SecurityFilter", str]) -> bool:
+        """Apply a security filter to the user.
+
+        Args:
+            security_filter (string or object): identifier of security filter or
+                `SecurityFilter` object which will be applied to the user.
+        Returns:
+            True when applying was successful. False otherwise.
+        """
+        if isinstance(security_filter, str):
+            from mstrio.access_and_security.security_filter import SecurityFilter
+            security_filter = SecurityFilter.from_dict({"id": security_filter}, self.connection)
+        return security_filter.apply(self.id)
+
+    def revoke_security_filter(self, security_filter: Union["SecurityFilter", str]) -> bool:
+        """Revoke a security filter from the user.
+
+        Args:
+            security_filter (string or object): identifier of security filter or
+                `SecurityFilter` object which will be revoked from the user.
+
+        Returns:
+            True when revoking was successful. False otherwise.
+        """
+        if isinstance(security_filter, str):
+            from mstrio.access_and_security.security_filter import SecurityFilter
+            security_filter = SecurityFilter.from_dict({"id": security_filter}, self.connection)
+        return security_filter.revoke(self.id)
+
     def grant_privilege(self, privilege: Union[str, List[str], "Privilege",
                                                List["Privilege"]]) -> None:
         """Grant privileges directly to the user.
@@ -615,7 +576,7 @@ class User(Entity):
         """Revoke directly granted user privileges.
 
         Args:
-            force: If True, no additional prompt will be showed before revoking
+            force: If True, no additional prompt will be shown before revoking
                 all privileges from User.
         """
         user_input = 'N'
