@@ -1,17 +1,18 @@
+from abc import ABCMeta, abstractmethod
+from ast import literal_eval
 import csv
 import json
 import pickle
-from abc import ABCMeta, abstractmethod
 from pprint import pprint
 from sys import version_info
-from typing import List, Dict, Optional, Union
-from ast import literal_eval
+from typing import Dict, List, Optional, Union
 import warnings
 
-import mstrio.config as config
-import mstrio.utils.helper as helper
 from pandas import DataFrame, Series
 
+from mstrio import config
+import mstrio.utils.helper as helper
+
 
 class BaseSettings(metaclass=ABCMeta):
     """Base class for fetching and updating Application or Server Settings. The
